=======================
You've got a good start
=======================

So here we are.  You've created a site and you're ready to start making files.

It's best you check the documentation.

Quick-start
-----------

You may have already done this, but if not it takes about 5 minutes to reach the
end and is a good primer.

API Reference
-------------

Goes into detail regarding the ins and outs of how Handcrank operates.

`Visit the documentation on PyPi <http://packages.python.org/handcrank>`_
